import domain from '../../domainFactory'

const CRITEO_ACCOUNT_NUMBER = 5426

const getCriteoDevice = () => {
  const userAgent = navigator.userAgent
  const touchStartEvent = 'ontouchstart' in document.documentElement
  if (/Mobi/.test(userAgent)) {
    return 'm'
  } else {
    if (!touchStartEvent) {
      return 'd'
    } else {
      return 't'
    }
  }
}

const notLoggedUserHomeEvent = () => {
  window.criteo_q = window.criteo_q || []
  window.criteo_q.push(
    {event: 'setAccount', account: CRITEO_ACCOUNT_NUMBER},
    {event: 'setCustomerId', id: ''},
    {event: 'setSiteType', type: getCriteoDevice()},
    {event: 'viewHome'}
  )
}

const createCandidateProfileEvent = () => {
  window.criteo_q = window.criteo_q || []
  window.criteo_q.push(
    {event: 'setAccount', account: CRITEO_ACCOUNT_NUMBER},
    {event: 'setCustomerId', id: ''},
    {event: 'setSiteType', type: getCriteoDevice()}
  )
}

const offerDetailEvent = async () => {
  const getOfferCode = window.location.pathname.match(/of-i(\w*)/)
  const [, offerCode] = getOfferCode
  const user = await domain.get('get_current_candidate_use_case').execute()
  window.criteo_q = window.criteo_q || []
  window.criteo_q.push(
    {event: 'setAccount', account: CRITEO_ACCOUNT_NUMBER},
    {event: 'setCustomerId', id: user ? user.cvCode : ''},
    {event: 'setSiteType', type: getCriteoDevice()},
    {event: 'viewItem', item: offerCode}
  )
}

const applicationPageEvent = async () => {
  const aplicationId = document.getElementsByName('applicationId')[0]?.value
  const offerId = document.getElementsByName('offerId')[0]?.value
  const cvId = document.getElementsByName('cvId')[0]?.value
  const deduplication = document.getElementsByName('deduplication')[0]?.value
  window.criteo_q = window.criteo_q || []
  window.criteo_q.push(
    {event: 'setAccount', account: CRITEO_ACCOUNT_NUMBER},
    {event: 'setCustomerId', id: cvId},
    {event: 'setSiteType', type: getCriteoDevice()},
    {
      event: 'trackTransaction',
      id: aplicationId,
      new_customer: 0,
      deduplication,
      item: [{id: offerId, price: 0, quantity: 1}]
    }
  )
}
const PAGE_EVENTS = {
  'Not logged user home': notLoggedUserHomeEvent,
  'Create candidate profile': createCandidateProfileEvent,
  'Offer detail': offerDetailEvent,
  'Application page': applicationPageEvent
}

const dispatchCriteoEvent = ({criteoPageName}) => {
  console.log('Dispatch del criteo event para la pagina', criteoPageName)
  PAGE_EVENTS[criteoPageName]()
}
export default dispatchCriteoEvent
